@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1101';
+our $VERSION = '0.1103';
 
 use Moo;
 use Music::Chord::Note;
@@ -123,6 +123,8 @@ sub cadence {
         push @$cadence, $chord;
 
         $chord = $self->_generate_chord( $scale, $scale[4], $octave, $mtr, $mcn );
+        $chord = $self->_invert_chord( $chord, $inversion->{2}, $octave )
+            if $inversion && $inversion->{2};
         push @$cadence, $chord;
     }
     elsif ( $type eq 'deceptive' ) {
@@ -157,10 +159,18 @@ sub _invert_chord {
 
         $pitches = $mcp->chord_inv( $pitches, inv_num => $inversion );
 
-        $chord = [ map { Music::Note->new( $_, 'midinum' )->format('isobase') } @$pitches ];
+        $chord = [ map { Music::Note->new( $_, 'midinum' )->format('ISO') } @$pitches ];
 
-        $chord = [ map { $_ . $octave } @$chord ]
-            if $octave;
+        for ( @$chord ) {
+            if ( $octave ) {
+                s/-1/$octave/;
+                s/0/++$octave/e;
+            }
+            else {
+                s/-1//;
+                s/0//;
+            }
+        }
     }
 
     return $chord;
@@ -228,7 +238,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1101
+version 0.1103
 
 =head1 SYNOPSIS
 
@@ -424,8 +434,8 @@ this is:
   Am: 6
   Bo: 7
 
-If an B<inversion> is defined for the C<half> cadence, the first chord
-is inverted.
+If an B<inversion> is defined for the C<half> cadence, the chords are
+inverted as described above for the C<imperfect> cadence.
 
 =head1 TO DO
 
